import { Logging } from "homebridge";
import { inject } from "tsyringe";
import { HarmonyDataProvider2 } from "../DataProviders/harmonyDataProvider2";
import { StateDataProvider } from "../DataProviders/stateDataProvider";
import { IConfig } from "../Models/Config";
import { HarmonyDevice } from "../Models/harmonyDevice";

export class VolumeService {
  constructor(
    @inject(StateDataProvider) private _stateDataProvider: StateDataProvider,
    @inject(HarmonyDataProvider2)
    private _harmonyDataProvider: HarmonyDataProvider2
  ) {}

  /**
   * Turn the volume up for the current running activity.
   */
  public volumeUp = async (controlUnitName: string) => {
    let volumeUpCommand: string = "Volume Up";
    let currentActivity = this._stateDataProvider.getState(controlUnitName);
    if (currentActivity) {
      let volumeDevice: HarmonyDevice =
        this._harmonyDataProvider.getDeviceFromName(
          currentActivity.VolumeDevice
        );
      await volumeDevice.sendCommand(volumeUpCommand);
    }
  };

  /**
   * Volume down for current running activity.
   */
  public volumeDown = async (controlUnitName: string) => {
    let volumeDownCommand: string = "Volume Down";
    let currentActivity = this._stateDataProvider.getState(controlUnitName);
    if (currentActivity) {
      let volumeDevice: HarmonyDevice =
        this._harmonyDataProvider.getDeviceFromName(
          currentActivity.VolumeDevice
        );
      await volumeDevice.sendCommand(volumeDownCommand);
    }
  };
}
